summaryrefslogtreecommitdiff
path: root/irsnd.c
diff options
context:
space:
mode:
authorukw2011-01-25 17:06:01 +0000
committerukw2011-01-25 17:06:01 +0000
commit779fbc81da759376eaf8eeb8fb0fda639e376c55 (patch)
tree3566b0c3ea5751f6889187ed93dc7cc3018bea62 /irsnd.c
parent894dee2fd1bc197a8b5d32444eaab142236463a2 (diff)
downloadirmp-779fbc81da759376eaf8eeb8fb0fda639e376c55.zip
corrected modulation frequency for denon protocol in irsnd.c, corrected #if for toggle_bit_rc6.
git-svn-id: svn://mikrocontroller.net/irmp@52 aeb2e35e-bfc4-4214-b83c-9e8de998ed28
Diffstat (limited to 'irsnd.c')
-rw-r--r--irsnd.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/irsnd.c b/irsnd.c
index 3cbe8d5..da09960 100644
--- a/irsnd.c
+++ b/irsnd.c
@@ -331,7 +331,7 @@ irsnd_send_data (IRMP_DATA * irmp_data_p, uint8_t do_wait)
#if IRSND_SUPPORT_RC5_PROTOCOL == 1
static uint8_t toggle_bit_rc5;
#endif
-#if IRSND_SUPPORT_RC5_PROTOCOL == 1
+#if IRSND_SUPPORT_RC6_PROTOCOL == 1 || IRSND_SUPPORT_RC6A_PROTOCOL == 1
static uint8_t toggle_bit_rc6;
#endif
uint16_t address;
@@ -1006,7 +1006,7 @@ irsnd_ISR (void)
n_auto_repetitions = DENON_FRAMES; // 2 frames, 2nd with inverted command
auto_repetition_pause_len = DENON_AUTO_REPETITION_PAUSE_LEN; // 65 ms pause after 1st frame
repeat_frame_pause_len = DENON_FRAME_REPEAT_PAUSE_LEN;
- irsnd_set_freq (IRSND_FREQ_38_KHZ); // in theory 32kHz, in practice 38kHz
+ irsnd_set_freq (IRSND_FREQ_36_KHZ); // in theory 32kHz, in practice 36kHz is better
break;
}
#endif